@@ -15,7 +15,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gst2perl.h,v 1.5 2005/06/01 18:01:15 kaffeetisch Exp $
+ * $Id: gst2perl.h,v 1.7 2005/12/19 00:26:40 kaffeetisch Exp $
  */
 
 #ifndef _GST2PERL_H_
@@ -28,6 +28,15 @@
 #include "gst2perl-version.h"
 #include "gst2perl-autogen.h"
 
+/* GstMiniObject support. */
+void gst2perl_register_mini_object (GType type, const char *package);
+
+typedef const char * (*Gst2PerlMiniObjectPackageLookupFunc) (GstMiniObject *object);
+void gst2perl_register_mini_object_package_lookup_func (GType type, Gst2PerlMiniObjectPackageLookupFunc func);
+
+SV * gst2perl_sv_from_mini_object (GstMiniObject *object, gboolean own);
+GstMiniObject * gst2perl_mini_object_from_sv (SV *sv);
+
 /* Custom enum handling. */
 #undef newSVGstFormat
 #undef SvGstFormat
@@ -39,12 +48,13 @@ GstFormat SvGstFormat (SV *sv);
 SV * newSVGstQueryType (GstQueryType type);
 GstQueryType SvGstQueryType (SV *sv);
 
-/* Custom type conversion. */
-SV * newSVGstEventMask (GstEventMask *mask);
-
-SV * newSVGstStructure (GstStructure *structure);
+/* Custom type converters. */
+SV * newSVGstStructure (const GstStructure *structure);
 GstStructure * SvGstStructure (SV *sv);
 
+SV * newSVGstIterator (const GstIterator *iter);
+GstIterator * SvGstIterator (SV *sv);
+
 SV * newSVGstClockTime (GstClockTime time);
 GstClockTime SvGstClockTime (SV *time);
 
@@ -54,21 +64,4 @@ GstClockTimeDiff SvGstClockTimeDiff (SV *diff);
 SV * newSVGstClockID (GstClockID id);
 GstClockID SvGstClockID (SV *sv);
 
-/* Stupid hacks. */
-void gst2perl_event_initialize (void);
-void gst2perl_value_initialize (void);
-
-/* Even yet one more stupid hack. */
-#undef SvGstSeekType
-GstSeekType SvGstSeekType (SV *type);
-
-/* Hacks to get large integers working. */
-typedef gint64 GstInt64;
-SV * newSVGstInt64 (gint64 value);
-gint64 SvGstInt64 (SV *sv);
-
-typedef guint64 GstUInt64;
-SV * newSVGstUInt64 (guint64 value);
-guint64 SvGstUInt64 (SV *sv);
-
 #endif /* _GST2PERL_H_ */
